==> vaycore-0.2.1.tar.gz: lib/utils/shared_preferences_utils.dart <==
import 'package:shared_preferences/shared_preferences.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-10
///

/// Shared Preferences 存储工具类
class SpUtils {
  static SpUtils _instance;

  SharedPreferences _sp;

  static Future<SpUtils> getInstance() async {
    if (_instance == null) {
      _instance = SpUtils._internal();
      await _instance._init();
    }
    return _instance;
  }

  SpUtils._internal();

  _init() async {
    _sp = await SharedPreferences.getInstance();
  }

  _checkInit() {
    assert(_sp != null, "SpUtils isn't init success!");
  }

  bool hasKey(String key) {
    Set keys = getKeys();
    return keys.contains(key);
  }

  Set<String> getKeys() {
    _checkInit();
    return _sp.getKeys();
  }

  get(String key) {
    _checkInit();
    return _sp.get(key);
  }

  getString(String key) {
    _checkInit();
    return _sp.getString(key);
  }

  Future<bool> putString(String key, String value) {
    _checkInit();
    return _sp.setString(key, value);
  }

  bool getBool(String key) {
    _checkInit();
    return _sp.getBool(key);
  }

  Future<bool> putBool(String key, bool value) {
    _checkInit();
    return _sp.setBool(key, value);
  }

  int getInt(String key) {
    _checkInit();
    return _sp.getInt(key);
  }

  Future<bool> putInt(String key, int value) {
    _checkInit();
    return _sp.setInt(key, value);
  }

  double getDouble(String key) {
    _checkInit();
    return _sp.getDouble(key);
  }

  Future<bool> putDouble(String key, double value) {
    _checkInit();
    return _sp.setDouble(key, value);
  }

  List<String> getStringList(String key) {
    return _sp.getStringList(key);
  }

  Future<bool> putStringList(String key, List<String> value) {
    _checkInit();
    return _sp.setStringList(key, value);
  }

  dynamic getDynamic(String key) {
    _checkInit();
    return _sp.get(key);
  }

  Future<bool> remove(String key) {
    _checkInit();
    return _sp.remove(key);
  }

  Future<bool> clear() {
    _checkInit();
    return _sp.clear();
  }
}

==> vaycore-0.5.2.tar.gz: lib/utils/shared_preferences_utils.dart <==
import 'package:shared_preferences/shared_preferences.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-10
///

/// Shared Preferences 存储工具类
class SpUtils {
  static SpUtils _instance;

  SharedPreferences _sp;

  static Future<SpUtils> getInstance() async {
    if (_instance == null) {
      _instance = SpUtils._();
      await _instance._init();
    }
    return _instance;
  }

  SpUtils._();

  _init() async {
    _sp = await SharedPreferences.getInstance();
  }

  _checkInit() {
    assert(_sp != null, "SpUtils isn't init success!");
  }

  bool hasKey(String key) {
    Set keys = getKeys();
    return keys.contains(key);
  }

  Set<String> getKeys() {
    _checkInit();
    return _sp.getKeys();
  }

  get(String key) {
    _checkInit();
    return _sp.get(key);
  }

  getString(String key) {
    _checkInit();
    return _sp.getString(key);
  }

  Future<bool> putString(String key, String value) {
    _checkInit();
    return _sp.setString(key, value);
  }

  bool getBool(String key) {
    _checkInit();
    return _sp.getBool(key);
  }

  Future<bool> putBool(String key, bool value) {
    _checkInit();
    return _sp.setBool(key, value);
  }

  int getInt(String key) {
    _checkInit();
    return _sp.getInt(key);
  }

  Future<bool> putInt(String key, int value) {
    _checkInit();
    return _sp.setInt(key, value);
  }

  double getDouble(String key) {
    _checkInit();
    return _sp.getDouble(key);
  }

  Future<bool> putDouble(String key, double value) {
    _checkInit();
    return _sp.setDouble(key, value);
  }

  List<String> getStringList(String key) {
    return _sp.getStringList(key);
  }

  Future<bool> putStringList(String key, List<String> value) {
    _checkInit();
    return _sp.setStringList(key, value);
  }

  dynamic getDynamic(String key) {
    _checkInit();
    return _sp.get(key);
  }

  Future<bool> remove(String key) {
    _checkInit();
    return _sp.remove(key);
  }

  Future<bool> clear() {
    _checkInit();
    return _sp.clear();
  }
}
